@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """GetB2G is a module designed to set up everything you need
-to run B2G builds and tests in one convenient directory. You 
-can run with no additional arguments to be dropped into an 
+to run B2G builds and tests in one convenient directory. You
+can run with no additional arguments to be dropped into an
 interactive session designed to help figure out what you need.
 """
 
@@ -11,7 +11,7 @@ import sys
 
 from base import valid_resources
 from errors import MultipleDeviceResourceException
-from prompt import prompt_resources 
+from prompt import prompt_resources
 from request import Request
 import prompt
 import mozlog
@@ -29,6 +29,17 @@ def cli(args=sys.argv[1:]):
     parser.add_option('-d', '--workdir', dest='workdir',
                       action='store', default=os.path.join(os.getcwd(), 'b2g-workdir'),
                       help='Set up everything in this directory')
+    for resource in valid_resources['cli'].difference(valid_resources['default']):
+        cmdlet = resource.replace('_', '-')
+        parser.add_option('--prepare-%s' % cmdlet, dest=resource,
+                          action='store_true', default=False,
+                          help='Do whatever it takes to set up %s' % resource)
+    parser.add_option('-m', '--metadata', dest='metadata',
+                      action='append', default=[],
+                      help='Append a piece of metadata in the form <key>=<value>. '
+                           'Attempt to use this metadata wherever it makes sense. '
+                           'Store values of duplicate keys in a list. E.g --metadata '
+                           'user=foo --metadata user=bar --metadata branch=mozilla-central')
     parser.add_option('--no-prompt', dest='prompt_disabled',
                       action='store_true', default=False,
                       help='Never prompt me for any additional '
@@ -41,21 +52,28 @@ def cli(args=sys.argv[1:]):
                       type='choice', default='INFO',
                       choices=['DEBUG', 'INFO', 'WARNING', 'ERROR'],
                       help='Only print messages at this log level')
-    for resource in valid_resources['cli'].difference(valid_resources['default']):
-        cmdlet = resource.replace('_', '-')
-        parser.add_option('--prepare-%s' % cmdlet, dest=resource,
-                          action='store_true', default=False,
-                          help='Do whatever it takes to set up %s' % resource)
-    parser.add_option('-m', '--metadata', dest='metadata',
-                      action='append', default=[],
-                      help='Append a piece of metadata in the form <key>=<value>. ' 
-                           'Attempt to use this metadata wherever it makes sense. '
-                           'Store values of duplicate keys in a list. E.g --metadata '
-                           'user=foo --metadata user=bar --metadata branch=mozilla-central')
     options, args = parser.parse_args(args)
     log.setLevel(getattr(mozlog, options.log_level))
     prompt.prompt_disabled = options.prompt_disabled
 
+
+    # disable localstorage
+    if len(args) > 0:
+        if args[0] == 'no-store':
+            db = os.path.expanduser(os.path.join('~', '.getb2g', 'storage.db'))
+            if os.path.isfile(db):
+                os.remove(db)
+            f = open(os.path.join(os.path.dirname(db), 'no-store'), 'w')
+            f.close()
+            return
+        elif args[0] == 'store':
+            store = os.path.join(os.path.expanduser(os.path.join('~', '.getb2g', 'no-store')))
+            if os.path.isfile(store):
+                os.remove(store)
+            return
+        else:
+            parser.error("Unrecognized argument '%s'" % args[0])
+
     metadata = {}
     if not os.path.isdir(options.workdir):
         os.makedirs(options.workdir)
@@ -68,7 +86,7 @@ def cli(args=sys.argv[1:]):
             metadata[k].append(v)
         else:
             metadata[k] = v
-   
+
     resources = set([r for r in valid_resources['all'] if getattr(options, r, False)])
     device = resources.intersection(valid_resources['device'])
     if len(device) > 1:
