@@ -5,15 +5,17 @@ prompt_disabled = False
 
 def prompt(question, valid_answers=None):
     if prompt_disabled:
-        return False
+        return
+
+    if valid_answers is None:
+        valid_answers = ('y','n')
 
-    valid_answers = valid_answers or ('y','n')
     while True:
-        print "%s (%s)" % (question, ', '.join(valid_answers))
+        print "%s%s" % (question, ' (%s)' % ', '.join(valid_answers) if valid_answers else '')
         ans = raw_input("$ ").lower()
         if ans == 'q':
             sys.exit(0)
-        if ans not in valid_answers:
+        if valid_answers and ans not in valid_answers:
             print "'%s' is not a valid option" % ans
             continue
         return ans
@@ -44,10 +46,10 @@ def prompt_user_pass(url, user=None, password=None):
     Prompts the user to provide any missing authentication information
     """
     if prompt_disabled:
-        return (user, password) 
+        return (user, password)
 
     if not user or not password:
         if prompt("Do you have a user name and password for '%s'?" % url) == 'y':
             user = raw_input("Username: ")
             password = getpass.getpass()
-    return (user, password) 
+    return (user, password)
